@@ -91,7 +91,7 @@ default_args = {
             'start_date': datetime.datetime(2020, 7, 2, 8, 0),
             'email_on_failure': False,
             'email_on_retry': False,
-            'execution_timeout': datetime.timedelta(minutes=180),
+            'execution_timeout': datetime.timedelta(seconds=10800),
 }
 
 dag = DAG(
@@ -112,7 +112,8 @@ tjob1 = kubernetes_pod_operator.KubernetesPodOperator(
     is_delete_operator_pod=True,
     retries=10,
     retry_delay=datetime.timedelta(seconds=20),
-    dag=dag)
+    dag=dag,
+    execution_timeout=datetime.timedelta(seconds=10800))
 
 
 tjob2 = kubernetes_pod_operator.KubernetesPodOperator(
@@ -125,7 +126,8 @@ tjob2 = kubernetes_pod_operator.KubernetesPodOperator(
     is_delete_operator_pod=True,
     retries=100,
     retry_delay=datetime.timedelta(seconds=200),
-    dag=dag)
+    dag=dag,
+    execution_timeout=datetime.timedelta(seconds=10800))
 
 tjob2.set_upstream(tjob1)
 
@@ -139,7 +141,8 @@ tjob3 = kubernetes_pod_operator.KubernetesPodOperator(
     is_delete_operator_pod=True,
     retries=100,
     retry_delay=datetime.timedelta(seconds=200),
-    dag=dag)
+    dag=dag,
+    execution_timeout=datetime.timedelta(seconds=10800))
 
 tjob3.set_upstream(tjob2)
 tjob3.set_upstream(tjob1)
@@ -187,7 +190,7 @@ default_args = {
             'start_date': datetime.datetime(2020, 7, 1, 0, 0),
             'email_on_failure': False,
             'email_on_retry': False,
-            'execution_timeout': datetime.timedelta(minutes=180),
+            'execution_timeout': datetime.timedelta(seconds=10800),
 }
 
 dag = DAG(
@@ -208,7 +211,8 @@ tjob1 = kubernetes_pod_operator.KubernetesPodOperator(
     is_delete_operator_pod=True,
     retries=10,
     retry_delay=datetime.timedelta(seconds=20),
-    dag=dag)
+    dag=dag,
+    execution_timeout=datetime.timedelta(seconds=10800))
 
 '''
         self.assert_files_are_equal(expected_dag_content, dag_file_content)
@@ -252,7 +256,7 @@ default_args = {
             'start_date': datetime.datetime(2020, 7, 1, 0, 0),
             'email_on_failure': False,
             'email_on_retry': False,
-            'execution_timeout': datetime.timedelta(minutes=180),
+            'execution_timeout': datetime.timedelta(seconds=10800),
 }
 
 dag = DAG(
@@ -273,7 +277,8 @@ tjob1 = kubernetes_pod_operator.KubernetesPodOperator(
     is_delete_operator_pod=True,
     retries=10,
     retry_delay=datetime.timedelta(seconds=20),
-    dag=dag)
+    dag=dag,
+    execution_timeout=datetime.timedelta(seconds=10800))
 
 '''
         self.assert_files_are_equal(expected_dag_content, dag_file_content)
